@@ -57,7 +57,7 @@ class privateapps(netskope.nss):
     '''
 
     # Generic Methods
-    def get(self, objpath, id="", action="", **params):
+    def get(self, objpath, id=""):
         '''
         Generic get object wrapper for ddi objects
 
@@ -71,8 +71,7 @@ class privateapps(netskope.nss):
         '''
         # Build url
         url = self.privateapps_url + objpath
-        url = self._use_obj_id(url, id=id, action=action)
-        url = self._add_params(url, **params)
+        url = self._use_obj_id(url, id=id)
         logging.debug("URL: {}".format(url))
 
         response = self._apiget(url)
@@ -209,6 +208,7 @@ class privateapps(netskope.nss):
         '''
 
         # Make API Call
+        id = []
         response = self.get(objpath)
 
         # Process response
@@ -220,17 +220,18 @@ class privateapps(netskope.nss):
                     app_id = app["app_id"]
                     app_name = app["app_name"]
                     host = app["host"]
-                    if key == 'app_name' and app_name in value:
-                        id = app_id
-                    elif key == 'host' and host in value:
-                        id = app_id
+                    if key == 'app_name' and value in app_name:
+                        id.append(app_id)
+                    elif key == 'host' and value in host:
+                        id.append(app_id)                       
                     else:
                         logging.debug("Key {} with value {} not found."
-                                  .format(key,value))
-                    logging.debug("id: {}".format(id)) 
-                    return id                        
+                                  .format(key,value))                       
             else:
                 logging.debug("Object Type " + objecttype + " not supported.")
+            
+            logging.debug("id: {}".format(id)) 
+            return id 
 
 
     def search_response(self, response, key="", value="", include_path=False):
